@@ -247,6 +247,9 @@ flames_err shift_FF_n(allflats *allflatsin, orderpos *ordpos, double yshift,
     if ((mid_stat=SCKGETC(DRS_VERBOSITY, 1, 3, &actvals, drs_verbosity))
                     != 0) {
         /* the keyword seems undefined, protest... */
+    	free(fitdata.offset);
+    	free(fitdata.value);
+    	free(fitdata.sigma);
         return(MAREMMA);
     }
 
@@ -273,10 +276,16 @@ flames_err shift_FF_n(allflats *allflatsin, orderpos *ordpos, double yshift,
      this x */
             /* bail out if the function call return an error status */
             if ((status = get_ordpos(ordpos, order, x, &ordercentre))!=NOERR) {
+            	free(fitdata.offset);
+            	free(fitdata.value);
+            	free(fitdata.sigma);
                 return(status);
             }
             myshiftdata->ordercentre = ordercentre;
             if ((status = get_ordslope(ordpos, order, x, &orderslope))!=NOERR) {
+            	free(fitdata.offset);
+            	free(fitdata.sigma);
+            	free(fitdata.value);
                 return(status);
             }
             myshiftdata->orderslope = orderslope;
@@ -294,6 +303,9 @@ flames_err shift_FF_n(allflats *allflatsin, orderpos *ordpos, double yshift,
             myshiftdata = shiftdata+ix;
             if ((status=calcshifts(allflatsin, shiftdata, iframe, ix, yshift))
                             != NOERR) {
+            	free(fitdata.offset);
+            	free(fitdata.sigma);
+            	free(fitdata.value);
                 return(status);
             }
             /* loop over lit fibres in this frame */
@@ -320,6 +332,9 @@ flames_err shift_FF_n(allflats *allflatsin, orderpos *ordpos, double yshift,
                     if ((status=locatefibre(allflatsin, allflatsout, ordpos,
                                     shiftdata, iorder, ifibre, ix, yshift))
                                     != NOERR) {
+                    	free(fitdata.offset);
+                    	free(fitdata.sigma);
+                    	free(fitdata.value);
                         return(status);
                     }
 
